pub struct ActionEvaluation {
pub list_id: String,
pub action_index: usize,
pub status: EvaluationStatus,
pub rejection_reason: Option<String>,
}Expand description
Per-action evaluation outcome.
Fields
list_id: Stringaction_index: usizestatus: EvaluationStatusrejection_reason: Option<String>Trait Implementations
Sourceimpl Clone for ActionEvaluation
impl Clone for ActionEvaluation
Sourcefn clone(&self) -> ActionEvaluation
fn clone(&self) -> ActionEvaluation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionEvaluation
impl Debug for ActionEvaluation
Sourceimpl<'de> Deserialize<'de> for ActionEvaluation
impl<'de> Deserialize<'de> for ActionEvaluation
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ActionEvaluation, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ActionEvaluation, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ActionEvaluation> for JsValuewhere
ActionEvaluation: Serialize,
impl From<ActionEvaluation> for JsValuewhere
ActionEvaluation: Serialize,
Sourcefn from(value: ActionEvaluation) -> JsValue
fn from(value: ActionEvaluation) -> JsValue
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
impl FromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
Sourcetype Abi = <JsType as FromWasmAbi>::Abi
type Abi = <JsType as FromWasmAbi>::Abi
The Wasm ABI type that this converts from when coming back out from the
ABI boundary.
Sourceunsafe fn from_abi(
js: <ActionEvaluation as FromWasmAbi>::Abi,
) -> ActionEvaluation
unsafe fn from_abi( js: <ActionEvaluation as FromWasmAbi>::Abi, ) -> ActionEvaluation
Sourceimpl IntoWasmAbi for &ActionEvaluationwhere
ActionEvaluation: Serialize,
impl IntoWasmAbi for &ActionEvaluationwhere
ActionEvaluation: Serialize,
Sourcetype Abi = <JsType as IntoWasmAbi>::Abi
type Abi = <JsType as IntoWasmAbi>::Abi
The Wasm ABI type that this converts into when crossing the ABI
boundary.
Sourcefn into_abi(self) -> <&ActionEvaluation as IntoWasmAbi>::Abi
fn into_abi(self) -> <&ActionEvaluation as IntoWasmAbi>::Abi
Convert
self into Self::Abi so that it can be sent across the wasm
ABI boundary.Sourceimpl IntoWasmAbi for ActionEvaluationwhere
ActionEvaluation: Serialize,
impl IntoWasmAbi for ActionEvaluationwhere
ActionEvaluation: Serialize,
Sourcetype Abi = <JsType as IntoWasmAbi>::Abi
type Abi = <JsType as IntoWasmAbi>::Abi
The Wasm ABI type that this converts into when crossing the ABI
boundary.
Sourcefn into_abi(self) -> <ActionEvaluation as IntoWasmAbi>::Abi
fn into_abi(self) -> <ActionEvaluation as IntoWasmAbi>::Abi
Convert
self into Self::Abi so that it can be sent across the wasm
ABI boundary.Sourceimpl OptionFromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
impl OptionFromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
Sourcefn is_none(js: &<ActionEvaluation as FromWasmAbi>::Abi) -> bool
fn is_none(js: &<ActionEvaluation as FromWasmAbi>::Abi) -> bool
Tests whether the argument is a “none” instance. If so it will be
deserialized as
None, and otherwise it will be passed to
FromWasmAbi.Sourceimpl OptionIntoWasmAbi for ActionEvaluationwhere
ActionEvaluation: Serialize,
impl OptionIntoWasmAbi for ActionEvaluationwhere
ActionEvaluation: Serialize,
Sourcefn none() -> <ActionEvaluation as IntoWasmAbi>::Abi
fn none() -> <ActionEvaluation as IntoWasmAbi>::Abi
Returns an ABI instance indicating “none”, which JS will interpret as
the
None branch of this option. Read moreSourceimpl RefFromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
impl RefFromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ActionEvaluation>
type Anchor = SelfOwner<ActionEvaluation>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceunsafe fn ref_from_abi(
js: <ActionEvaluation as RefFromWasmAbi>::Abi,
) -> <ActionEvaluation as RefFromWasmAbi>::Anchor
unsafe fn ref_from_abi( js: <ActionEvaluation as RefFromWasmAbi>::Abi, ) -> <ActionEvaluation as RefFromWasmAbi>::Anchor
Sourceimpl Serialize for ActionEvaluation
impl Serialize for ActionEvaluation
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl Tsify for ActionEvaluation
impl Tsify for ActionEvaluation
const DECL: &'static str = "/**\n * Per-action evaluation outcome.\n */\nexport interface ActionEvaluation {\n listId: string;\n actionIndex: number;\n status: EvaluationStatus;\n rejectionReason?: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
impl VectorFromWasmAbi for ActionEvaluationwhere
ActionEvaluation: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi( js: <ActionEvaluation as VectorFromWasmAbi>::Abi, ) -> Box<[ActionEvaluation]>
Sourceimpl VectorIntoWasmAbi for ActionEvaluationwhere
ActionEvaluation: Serialize,
impl VectorIntoWasmAbi for ActionEvaluationwhere
ActionEvaluation: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi( vector: Box<[ActionEvaluation]>, ) -> <ActionEvaluation as VectorIntoWasmAbi>::Abi